/*****************************************************************************************
*                                                                                        *
* This SAS program will extract the United States Sentencing Commission's fiscal year    *
* 2003 Organizational file and create a SAS dataset.                                     *
*                                                                                        *
* Prior to running the program you must update the DAT file location in the FILNAME line *
* to correspond to the location of the file on your computer, replacing the '.' with the *
* folder path location (e.g. 'C:\temp') .                                                *
*                                                                                        *
* You must also update the library location in the LIBNAME statement to correspond to    *
* the folder you want the output file to be located, replacing the '.' with the folder   *
* path location (e.g. 'C:\temp') .                                                       *
*                                                                                        *
*****************************************************************************************/

/* The following line should contain the complete path and name of your raw data file */
FILENAME datafile '.\corp03nid.dat' ;

/* The following line should contain the directory in which you wish your SAS file to be stored */
libname library '.' ;

/* The following line contains the name (without the extension) for your SAS dataset */
%LET dataset = corp03nid ;

DATA library.&dataset ;
INFILE datafile LRECL=2400;
INPUT
   DISGORGE  1              CPIDN  2-5               AMENDYR  6-9          
   BUSTEXT $ 10-56          OWNSTEXT $ 57            FINSTXT $ 58-131      
   FINDOTXT $ 132-187       OFENTXT1 $ 188-230       OFENTXT2 $ 231        
   OFENTXT3 $ 232           PRMONTXT $ 233-332       ORDERTXT $ 333-432    
   REASTXT1 $ 433-500       REASTXT2 $ 501           REASTXT3 $ 502        
   REASTXT4 $ 503           OUTSOURC $ 504           PSR  505              
   JANDC  506               PLEA  507                REASONS  508          
   INDICT  509              SENTRANS  510            WRKSHT  511           
   INCORPYR  512-515        INCORLOC  516            ORGTYPE  517          
   BUSCLAS  518-521         FTEMNUM  522-527         FTEMSIGN  528         
   SELFREP  529             HSMISCND  530            PRCRIME  531          
   PRCIVIL  532             OWNSTRCT  533            FINSTDS  534          
   FINSTDO  535             PRIMOFF  536-537         NOCOUNTS  538-539     
   SOURCES  540             OFFLVL  541-542          DETBFINE  543         
   TOLERNCE  544            HISTORY  545             VIOLATE  546          
   OBSTRUCT  547            COMPLY  548-549          ACCEPT  550-551       
   CCULPSCO  552            FCULPSCO  553-554        MINFINML  555-557     
   MAXFINML  558-560        DISPOSIT  561            PROBATN  562-563      
   COFI  564                PROBMON  565             ORDERCE  566          
   TYPEOTHS  567-568        CRIMPURP  569            CANTPAY  570          
   DEPSOR  571              REASON1  572-574         REASON2  575          
   REASON3  576             REASON4  577             NOCOMP  578           
   ADJR_B1  579-580         ADJR_B2  581-582         ADJR_B3  583          
   ADJR_B4  584             ADJR_C1  585             ADJR_C2  586          
   ADJR_C3  587             ADJR_C4  588             ADJR_D1  589          
   ADJR_D2  590             ADJR_D3  591             ADJR_D4  592          
   ADJR_E1  593             ADJR_E2  594             ADJR_E3  595          
   ADJR_E4  596             ADJR_F1  597             ADJR_F2  598          
   ADJR_F3  599             ADJR_F4  600             ADJR_G1  601          
   ADJR_G2  602             ADJR_G3  603             ADJR_G4  604          
   ADJR_H1  605             ADJR_H2  606             ADJR_H3  607          
   ADJR_H4  608             ADJR_I1  609             ADJR_I2  610          
   ADJR_I3  611             ADJR_I4  612             ADJR_J1  613          
   ADJR_J2  614             ADJR_J3  615             ADJR_J4  616          
   ADJR_K1  617             ADJR_K2  618             ADJR_K3  619          
   ADJR_K4  620             ADJR_L1  621             ADJR_L2  622          
   ADJR_L3  623             ADJR_L4  624             ADJR_M1  625          
   ADJR_M2  626             ADJR_M3  627             ADJR_M4  628          
   ADJR_N1  629             ADJR_N2  630             ADJR_N3  631          
   ADJR_N4  632             ADJR_O1  633             ADJR_O2  634          
   ADJR_O3  635             ADJR_O4  636             ADJR_P1  637          
   ADJR_P2  638             ADJR_P3  639             ADJR_P4  640          
   ADJ_B1  641-642          ADJ_B2  643-644          ADJ_B3  645           
   ADJ_B4  646              ADJ_C1  647              ADJ_C2  648           
   ADJ_C3  649              ADJ_C4  650              ADJ_D1  651           
   ADJ_D2  652              ADJ_D3  653              ADJ_D4  654           
   ADJ_E1  655              ADJ_E2  656              ADJ_E3  657           
   ADJ_E4  658              ADJ_F1  659              ADJ_F2  660           
   ADJ_F3  661              ADJ_F4  662              ADJ_G1  663           
   ADJ_G2  664              ADJ_G3  665              ADJ_G4  666           
   ADJ_H1  667              ADJ_H2  668              ADJ_H3  669           
   ADJ_H4  670              ADJ_I1  671              ADJ_I2  672           
   ADJ_I3  673              ADJ_I4  674              ADJ_J1  675           
   ADJ_J2  676              ADJ_J3  677              ADJ_J4  678           
   ADJ_K1  679              ADJ_K2  680              ADJ_K3  681           
   ADJ_K4  682              ADJ_L1  683              ADJ_L2  684           
   ADJ_L3  685              ADJ_L4  686              ADJ_M1  687           
   ADJ_M2  688              ADJ_M3  689              ADJ_M4  690           
   ADJ_N1  691              ADJ_N2  692              ADJ_N3  693           
   ADJ_N4  694              ADJ_O1  695              ADJ_O2  696           
   ADJ_O3  697              ADJ_O4  698              ADJ_P1  699           
   ADJ_P2  700              ADJ_P3  701              ADJ_P4  702           
   BASADJ1  703-704         BASADJ2  705             BASADJ3  706          
   BASADJ4  707             BASADR1  708             BASADR2  709          
   BASADR3  710             BASADR4  711             BASE1  712-713        
   BASE2  714-715           BASE3  716-717           BASE4  718            
   BASER1  719-720          BASER2  721              BASER3  722-723       
   BASER4  724              GDLINE1 $ 725-729        GDLINE2 $ 730-734     
   GDLINE3 $ 735-739        GDLINE4 $ 740-744        GDREF1 $ 745-749      
   GDREF2 $ 750-754         GDREF3 $ 755-759         GDREF4 $ 760          
   GDSTAT1 $ 761-765        GDSTAT2 $ 766-770        GDSTAT3 $ 771-775     
   GDSTAT4 $ 776-780        ADJOFL1  781-782         ADJOFL2  783-784      
   ADJOFL3  785-786         ADJOFL4  787-788         ADJOFR1  789-790      
   ADJOFR2  791-792         ADJOFR3  793-794         ADJOFR4  795          
   GDSTATHI $ 796-800       GDLINEHI $ 801-805       ADJOFLHI  806-807     
   BASEHI  808-809          ADJ_BHI  810-811         ADJ_CHI  812          
   ADJ_DHI  813             ADJ_EHI  814             ADJ_FHI  815          
   ADJ_GHI  816             ADJ_HHI  817             ADJ_IHI  818          
   ADJ_JHI  819             ADJ_KHI  820             ADJ_LHI  821          
   ADJ_MHI  822             ADJ_NHI  823             ADJ_OHI  824          
   ADJ_PHI  825             BASADJHI  826-827        GDREFHI $ 828-832     
   BASERHI  833-834         ADJR_BHI  835-836        ADJR_CHI  837         
   ADJR_DHI  838            ADJR_EHI  839            ADJR_FHI  840         
   ADJR_GHI  841            ADJR_HHI  842            ADJR_IHI  843         
   ADJR_JHI  844            ADJR_KHI  845            ADJR_LHI  846         
   ADJR_MHI  847            ADJR_NHI  848            ADJR_OHI  849         
   ADJR_PHI  850            BASADRHI  851            ADJOFRHI  852-853     
   SMIN1  854-859           SMIN2  860-863           SMIN3  864            
   SMIN4  865               SMIN5  866               SMIN6  867            
   SMIN7  868               SMIN8  869               SMIN9  870            
   SMIN10  871              SMIN11  872              SMIN12  873           
   SMIN13  874              SMIN14  875              SMIN15  876           
   SMIN16  877              SMIN17  878              SMIN18  879           
   SMIN19  880              SMIN20  881              SMIN21  882           
   SMIN22  883              SMIN23  884              SMIN24  885           
   SMIN25  886              SMIN26  887              SMIN27  888           
   SMIN28  889              SMIN29  890              SMIN30  891           
   SMIN31  892              SMIN32  893              SMIN33  894           
   SMIN34  895              SMIN35  896              SMIN36  897           
   SMIN37  898              SMIN38  899              SMIN39  900           
   SMIN40  901              SMIN41  902              SMIN42  903           
   SMIN43  904              SMIN44  905              SMIN45  906           
   SMIN46  907              SMAX1  908-915           SMAX2  916-923        
   SMAX3  924-931           SMAX4  932-938           SMAX5  939-945        
   SMAX6  946-952           SMAX7  953-959           SMAX8  960-966        
   SMAX9  967-973           SMAX10  974-980          SMAX11  981-987       
   SMAX12  988-994          SMAX13  995-1001         SMAX14  1002-1008     
   SMAX15  1009-1015        SMAX16  1016-1022        SMAX17  1023-1029     
   SMAX18  1030-1036        SMAX19  1037-1043        SMAX20  1044-1050     
   SMAX21  1051-1057        SMAX22  1058-1064        SMAX23  1065-1071     
   SMAX24  1072-1077        SMAX25  1078-1083        SMAX26  1084-1089     
   SMAX27  1090-1095        SMAX28  1096-1101        SMAX29  1102-1107     
   SMAX30  1108-1113        SMAX31  1114-1119        SMAX32  1120-1125     
   SMAX33  1126-1131        SMAX34  1132-1137        SMAX35  1138-1143     
   SMAX36  1144-1149        SMAX37  1150-1155        SMAX38  1156-1161     
   SMAX39  1162-1167        SMAX40  1168-1173        SMAX41  1174-1179     
   SMAX42  1180-1185        SMAX43  1186-1191        SMAX44  1192-1197     
   SMAX45  1198-1203        SMAX46  1204-1209        STA1_1 $ 1210-1219    
   STA1_2 $ 1220-1229       STA1_3 $ 1230-1238       STA1_4 $ 1239-1248    
   STA1_5 $ 1249-1257       STA1_6 $ 1258-1267       STA1_7 $ 1268-1276    
   STA1_8 $ 1277-1286       STA1_9 $ 1287-1295       STA1_10 $ 1296-1304   
   STA1_11 $ 1305-1313      STA1_12 $ 1314-1322      STA1_13 $ 1323-1331   
   STA1_14 $ 1332-1340      STA1_15 $ 1341-1350      STA1_16 $ 1351-1360   
   STA1_17 $ 1361-1370      STA1_18 $ 1371-1380      STA1_19 $ 1381-1390   
   STA1_20 $ 1391-1400      STA1_21 $ 1401-1410      STA1_22 $ 1411-1420   
   STA1_23 $ 1421-1430      STA1_24 $ 1431-1440      STA1_25 $ 1441-1450   
   STA1_26 $ 1451-1460      STA1_27 $ 1461-1470      STA1_28 $ 1471-1480   
   STA1_29 $ 1481-1490      STA1_30 $ 1491-1500      STA1_31 $ 1501-1510   
   STA1_32 $ 1511-1520      STA1_33 $ 1521-1530      STA1_34 $ 1531-1540   
   STA1_35 $ 1541-1550      STA1_36 $ 1551-1560      STA1_37 $ 1561-1570   
   STA1_38 $ 1571-1580      STA1_39 $ 1581-1590      STA1_40 $ 1591-1600   
   STA1_41 $ 1601-1610      STA1_42 $ 1611-1620      STA1_43 $ 1621-1630   
   STA1_44 $ 1631-1640      STA1_45 $ 1641-1650      STA1_46 $ 1651-1660   
   STA2_1 $ 1661-1670       STA2_2 $ 1671-1679       STA2_3 $ 1680-1688    
   STA2_4 $ 1689-1698       STA2_5 $ 1699-1707       STA2_6 $ 1708-1717    
   STA2_7 $ 1718-1726       STA2_8 $ 1727-1736       STA2_9 $ 1737-1745    
   STA2_10 $ 1746-1754      STA2_11 $ 1755-1763      STA2_12 $ 1764-1772   
   STA2_13 $ 1773-1781      STA2_14 $ 1782-1790      STA2_15 $ 1791-1799   
   STA2_16 $ 1800-1808      STA2_17 $ 1809-1817      STA2_18 $ 1818-1826   
   STA2_19 $ 1827-1835      STA2_20 $ 1836-1844      STA2_21 $ 1845        
   STA2_22 $ 1846           STA2_23 $ 1847-1853      STA2_24 $ 1854-1860   
   STA2_25 $ 1861-1867      STA2_26 $ 1868-1874      STA2_27 $ 1875-1881   
   STA2_28 $ 1882-1888      STA2_29 $ 1889-1895      STA2_30 $ 1896        
   STA2_31 $ 1897           STA2_32 $ 1898           STA2_33 $ 1899        
   STA2_34 $ 1900           STA2_35 $ 1901           STA2_36 $ 1902        
   STA2_37 $ 1903           STA2_38 $ 1904           STA2_39 $ 1905        
   STA2_40 $ 1906           STA2_41 $ 1907           STA2_42 $ 1908        
   STA2_43 $ 1909           STA2_44 $ 1910           STA2_45 $ 1911        
   STA2_46 $ 1912           STA3_1 $ 1913-1921       STA3_2 $ 1922-1929    
   STA3_3 $ 1930-1935       STA3_4 $ 1936-1941       STA3_5 $ 1942-1947    
   STA3_6 $ 1948-1953       STA3_7 $ 1954-1959       STA3_8 $ 1960-1965    
   STA3_9 $ 1966-1971       STA3_10 $ 1972-1977      STA3_11 $ 1978-1983   
   STA3_12 $ 1984-1989      STA3_13 $ 1990-1995      STA3_14 $ 1996-2001   
   STA3_15 $ 2002-2007      STA3_16 $ 2008-2013      STA3_17 $ 2014-2019   
   STA3_18 $ 2020-2025      STA3_19 $ 2026           STA3_20 $ 2027        
   STA3_21 $ 2028           STA3_22 $ 2029           STA3_23 $ 2030        
   STA3_24 $ 2031           STA3_25 $ 2032           STA3_26 $ 2033        
   STA3_27 $ 2034           STA3_28 $ 2035           STA3_29 $ 2036        
   STA3_30 $ 2037           STA3_31 $ 2038           STA3_32 $ 2039        
   STA3_33 $ 2040           STA3_34 $ 2041           STA3_35 $ 2042        
   STA3_36 $ 2043           STA3_37 $ 2044           STA3_38 $ 2045        
   STA3_39 $ 2046           STA3_40 $ 2047           STA3_41 $ 2048        
   STA3_42 $ 2049           STA3_43 $ 2050           STA3_44 $ 2051        
   STA3_45 $ 2052           STA3_46 $ 2053           NWSTAT1 $ 2054-2063   
   NWSTAT2 $ 2064-2073      NWSTAT3 $ 2074-2082      NWSTAT4 $ 2083-2092   
   NWSTAT5 $ 2093-2102      NWSTAT6 $ 2103-2112      NWSTAT7 $ 2113-2115   
   NWSTAT8 $ 2116-2125      NOUSTAT  2126            BASEFINE  2127-2134   
   CH2APP  2135             CH8FINGD  2136           CMSRVORD  2137        
   COMPLYPR  2138           COSTASSM  2139           FINOFFST  2140-2147   
   FORFEITR  2148-2155      GLFINMAX  2156-2164      GLFINMIN  2165-2172   
   OFFENSE1  2173-2174      OFFENSE2  2175           OFFENSE3  2176        
   REMEDORD  2177-2179      VICTNOTE  2180           QUARTER  2181         
   SENTYR  2182-2185        TYPEOTTX $ 2186-2385     NEWCNVTN  2386        
   NOREAS  2387             RESTCAT  2388            FINECAT  2389         
   SUSFNCAT  2390           LCAT1  2391              LCAT2  2392           
   LCAT3  2393              LCAT4  2394              LCATHI  2395          
   LCATR1  2396             LCATR2  2397             LCATR3  2398          
   LCATR4  2399             LCATRHI  2400          ;                       

LENGTH
   DISGORGE 3               CPIDN 4                  AMENDYR 4             
   PSR 3                    JANDC 3                  PLEA 3                
   REASONS 3                INDICT 3                 SENTRANS 3            
   WRKSHT 3                 INCORPYR 4               INCORLOC 3            
   ORGTYPE 3                BUSCLAS 4                FTEMNUM 6             
   FTEMSIGN 3               SELFREP 3                HSMISCND 3            
   PRCRIME 3                PRCIVIL 3                OWNSTRCT 3            
   FINSTDS 3                FINSTDO 3                PRIMOFF 3             
   NOCOUNTS 3               SOURCES 3                OFFLVL 3              
   DETBFINE 3               TOLERNCE 3               HISTORY 3             
   VIOLATE 3                OBSTRUCT 3               COMPLY 3              
   ACCEPT 3                 CCULPSCO 3               FCULPSCO 3            
   DISPOSIT 3               PROBATN 3                COFI 3                
   PROBMON 3                ORDERCE 3                TYPEOTHS 3            
   CRIMPURP 3               CANTPAY 3                DEPSOR 3              
   REASON1 4                REASON2 3                REASON3 3             
   REASON4 3                NOCOMP 3                 ADJR_B1 3             
   ADJR_B2 3                ADJR_B3 3                ADJR_B4 3             
   ADJR_C1 3                ADJR_C2 3                ADJR_C3 3             
   ADJR_C4 3                ADJR_D1 3                ADJR_D2 3             
   ADJR_D3 3                ADJR_D4 3                ADJR_E1 3             
   ADJR_E2 3                ADJR_E3 3                ADJR_E4 3             
   ADJR_F1 3                ADJR_F2 3                ADJR_F3 3             
   ADJR_F4 3                ADJR_G1 3                ADJR_G2 3             
   ADJR_G3 3                ADJR_G4 3                ADJR_H1 3             
   ADJR_H2 3                ADJR_H3 3                ADJR_H4 3             
   ADJR_I1 3                ADJR_I2 3                ADJR_I3 3             
   ADJR_I4 3                ADJR_J1 3                ADJR_J2 3             
   ADJR_J3 3                ADJR_J4 3                ADJR_K1 3             
   ADJR_K2 3                ADJR_K3 3                ADJR_K4 3             
   ADJR_L1 3                ADJR_L2 3                ADJR_L3 3             
   ADJR_L4 3                ADJR_M1 3                ADJR_M2 3             
   ADJR_M3 3                ADJR_M4 3                ADJR_N1 3             
   ADJR_N2 3                ADJR_N3 3                ADJR_N4 3             
   ADJR_O1 3                ADJR_O2 3                ADJR_O3 3             
   ADJR_O4 3                ADJR_P1 3                ADJR_P2 3             
   ADJR_P3 3                ADJR_P4 3                ADJ_B1 3              
   ADJ_B2 3                 ADJ_B3 3                 ADJ_B4 3              
   ADJ_C1 3                 ADJ_C2 3                 ADJ_C3 3              
   ADJ_C4 3                 ADJ_D1 3                 ADJ_D2 3              
   ADJ_D3 3                 ADJ_D4 3                 ADJ_E1 3              
   ADJ_E2 3                 ADJ_E3 3                 ADJ_E4 3              
   ADJ_F1 3                 ADJ_F2 3                 ADJ_F3 3              
   ADJ_F4 3                 ADJ_G1 3                 ADJ_G2 3              
   ADJ_G3 3                 ADJ_G4 3                 ADJ_H1 3              
   ADJ_H2 3                 ADJ_H3 3                 ADJ_H4 3              
   ADJ_I1 3                 ADJ_I2 3                 ADJ_I3 3              
   ADJ_I4 3                 ADJ_J1 3                 ADJ_J2 3              
   ADJ_J3 3                 ADJ_J4 3                 ADJ_K1 3              
   ADJ_K2 3                 ADJ_K3 3                 ADJ_K4 3              
   ADJ_L1 3                 ADJ_L2 3                 ADJ_L3 3              
   ADJ_L4 3                 ADJ_M1 3                 ADJ_M2 3              
   ADJ_M3 3                 ADJ_M4 3                 ADJ_N1 3              
   ADJ_N2 3                 ADJ_N3 3                 ADJ_N4 3              
   ADJ_O1 3                 ADJ_O2 3                 ADJ_O3 3              
   ADJ_O4 3                 ADJ_P1 3                 ADJ_P2 3              
   ADJ_P3 3                 ADJ_P4 3                 BASADJ1 3             
   BASADJ2 3                BASADJ3 3                BASADJ4 3             
   BASADR1 3                BASADR2 3                BASADR3 3             
   BASADR4 3                BASE1 3                  BASE2 3               
   BASE3 3                  BASE4 3                  BASER1 3              
   BASER2 3                 BASER3 3                 BASER4 3              
   ADJOFL1 3                ADJOFL2 3                ADJOFL3 3             
   ADJOFL4 3                ADJOFR1 3                ADJOFR2 3             
   ADJOFR3 3                ADJOFR4 3                ADJOFLHI 3            
   BASEHI 3                 ADJ_BHI 3                ADJ_CHI 3             
   ADJ_DHI 3                ADJ_EHI 3                ADJ_FHI 3             
   ADJ_GHI 3                ADJ_HHI 3                ADJ_IHI 3             
   ADJ_JHI 3                ADJ_KHI 3                ADJ_LHI 3             
   ADJ_MHI 3                ADJ_NHI 3                ADJ_OHI 3             
   ADJ_PHI 3                BASADJHI 3               BASERHI 3             
   ADJR_BHI 3               ADJR_CHI 3               ADJR_DHI 3            
   ADJR_EHI 3               ADJR_FHI 3               ADJR_GHI 3            
   ADJR_HHI 3               ADJR_IHI 3               ADJR_JHI 3            
   ADJR_KHI 3               ADJR_LHI 3               ADJR_MHI 3            
   ADJR_NHI 3               ADJR_OHI 3               ADJR_PHI 3            
   BASADRHI 3               ADJOFRHI 3               SMIN1 6               
   SMIN2 4                  SMIN3 3                  SMIN4 3               
   SMIN5 3                  SMIN6 3                  SMIN7 3               
   SMIN8 3                  SMIN9 3                  SMIN10 3              
   SMIN11 3                 SMIN12 3                 SMIN13 3              
   SMIN14 3                 SMIN15 3                 SMIN16 3              
   SMIN17 3                 SMIN18 3                 SMIN19 3              
   SMIN20 3                 SMIN21 3                 SMIN22 3              
   SMIN23 3                 SMIN24 3                 SMIN25 3              
   SMIN26 3                 SMIN27 3                 SMIN28 3              
   SMIN29 3                 SMIN30 3                 SMIN31 3              
   SMIN32 3                 SMIN33 3                 SMIN34 3              
   SMIN35 3                 SMIN36 3                 SMIN37 3              
   SMIN38 3                 SMIN39 3                 SMIN40 3              
   SMIN41 3                 SMIN42 3                 SMIN43 3              
   SMIN44 3                 SMIN45 3                 SMIN46 3              
   SMAX1 6                  SMAX2 6                  SMAX3 6               
   SMAX4 6                  SMAX5 6                  SMAX6 6               
   SMAX7 6                  SMAX8 6                  SMAX9 6               
   SMAX10 6                 SMAX11 6                 SMAX12 6              
   SMAX13 6                 SMAX14 6                 SMAX15 6              
   SMAX16 6                 SMAX17 6                 SMAX18 6              
   SMAX19 6                 SMAX20 6                 SMAX21 6              
   SMAX22 6                 SMAX23 6                 SMAX24 6              
   SMAX25 6                 SMAX26 6                 SMAX27 6              
   SMAX28 6                 SMAX29 6                 SMAX30 6              
   SMAX31 6                 SMAX32 6                 SMAX33 6              
   SMAX34 6                 SMAX35 6                 SMAX36 6              
   SMAX37 6                 SMAX38 6                 SMAX39 6              
   SMAX40 6                 SMAX41 6                 SMAX42 6              
   SMAX43 6                 SMAX44 6                 SMAX45 6              
   SMAX46 6                 NOUSTAT 3                BASEFINE 6            
   CH2APP 3                 CH8FINGD 3               CMSRVORD 3            
   COMPLYPR 3               COSTASSM 3               FINOFFST 6            
   FORFEITR 6               GLFINMAX 6               GLFINMIN 6            
   OFFENSE1 3               OFFENSE2 3               OFFENSE3 3            
   REMEDORD 4               VICTNOTE 3               QUARTER 3             
   SENTYR 4                 NEWCNVTN 3               NOREAS 3              
   RESTCAT 3                FINECAT 3                SUSFNCAT 3            
   LCAT1 3                  LCAT2 3                  LCAT3 3               
   LCAT4 3                  LCATHI 3                 LCATR1 3              
   LCATR2 3                 LCATR3 3                 LCATR4 3              
   LCATRHI 3 ;

         

RUN ;
